@@ -12,6 +12,11 @@ pub enum DisplayHint {
         uppercase: bool,
         zero_pad: usize,
     },
+    /// `:o`
+    Octal {
+        alternate: bool,
+        zero_pad: usize,
+    },
     /// `:b`
     Binary {
         alternate: bool,
@@ -87,6 +92,10 @@ impl DisplayHint {
                 alternate,
                 zero_pad,
             },
+            "o" => DisplayHint::Octal {
+                alternate,
+                zero_pad,
+            },
             "x" => DisplayHint::Hexadecimal {
                 alternate,
                 uppercase: false,
